@@ -27,12 +27,12 @@ corsplom <- function(x,...)UseMethod('corsplom')
 #' @param main character, or a function of x, xvar
 #' @param sub character, or a function of x, xvar
 #' @param col point color
-#' @param smooth.col smooth color
+#' @param smooth.col smooth color, defaults to col
 #' @param smooth.lty smooth line type
 #' @param smooth.lwd smooth line size
 #' @param smooth.alpha smooth alpha
 #' @param density whether to plot density polygons
-#' @param diag.label label for the diagonal; can be a function of x, varname, .data
+#' @param diag.label label for the diagonal: a function of x, varname, .data
 #' @param pin location for a pin (reference line) in the density region; can be function(x, varname, .data) or NULL to suppress
 #' @param pin.col color of pin, if any
 #' @param pin.alpha alpha transparency of pin
@@ -44,6 +44,7 @@ corsplom <- function(x,...)UseMethod('corsplom')
 #' @param as.table diagonal arranged top-left to bottom-right
 #' @param dens.up whether density plots in diagonal should face the upper triangle vs. lower
 #' @param gg logical: whether to generate \code{ggplot} instead of \code{trellis}
+#' @param verbose generate messages describing process
 #' @param ... extra arguments passed to \code{\link[lattice]{splom}} and ggplot
 #' @export
 #' @return trellis or grob
@@ -63,7 +64,7 @@ corsplom <- function(x,...)UseMethod('corsplom')
 #' x <- as.csv(system.file(package = 'metaplot', 'extdata/theoph.csv'))
 #' x %<>% pack
 
-#' # options(metaplot_gg = TRUE)
+#' # setOption(gg = TRUE)
 
 #' x %>% metaplot(lKe, lKa, lCl)
 #' x %>% metaplot(
@@ -75,34 +76,37 @@ corsplom <- function(x,...)UseMethod('corsplom')
 corsplom_data_frame <- function(
   x,
   xvar = names(x),
-  upper.panel = metOption('metaplot_upperpanel_corsplom',if(gg) corsplom_gg_scatter else corsplom_panel_scatter),
-  lower.panel= metOption('metaplot_lowerpanel_corsplom',if(gg) corsplom_gg_correlation else corsplom_panel_correlation),
-  diag.panel = metOption('metaplot_diagpanel_corsplom',if(gg) corsplom_gg_diagonal else corsplom_panel_diagonal),
-  pscales= metOption('metaplot_pscales_corsplom',0),
-  xlab = metOption('metaplot_xlab_corsplom',NULL),
-  varname.cex = metOption('metaplot_varname_cex_corsplom',1),
-  main = metOption('metaplot_main_corsplom',NULL),
-  sub = metOption('metaplot_sub_corsplom',NULL),
-  col = metOption('metaplot_point_col_corsplom','blue'),
-  smooth.col = metOption('metaplot_smooth_col_corsplom',col),
-  smooth.lty = metOption('metaplot_smooth_lty_corsplom','solid'),
-  smooth.lwd = metOption('metaplot_smooth_lwd_corsplom',1),
-  smooth.alpha = metOption('metaplot_smooth_alpha_corsplom',1),
-  density = metOption('metaplot_density_corsplom',TRUE),
-  diag.label = metOption('metaplot_diag_label_corsplom',diag_label),
-  pin = metOption('metaplot_pin_loc_corsplom',diag_pin),
-  pin.col = metOption('metaplot_pin_col_corsplom','darkgrey'),
-  pin.alpha = metOption('metaplot_pin_alpha_corsplom',1),
-  dens.col = metOption('metaplot_dens_col_corsplom','grey'),
-  dens.scale = metOption('metaplot_dens_scale_corsplom',0.2),
-  dens.alpha = metOption('metaplot_dens_alpha_corsplom',0.5),
-  settings = metOption('metaplot_settings_corsplom',NULL),
-  padding = metOption('metaplot_padding_corsplom', 1),
-  as.table = metOption('metaplot_astable_corsplom', FALSE),
-  dens.up = metOption('metaplot_updens_corsplom', TRUE), # must not partial match metaplot_densplot or metaplot_upper
-  gg = metOption('metaplot_gg_corsplom',FALSE),
+  upper.panel = metOption('upper.panel_corsplom',if(gg) 'corsplom_gg_scatter' else 'corsplom_panel_scatter'),
+  lower.panel= metOption('lower.panel_corsplom',if(gg) 'corsplom_gg_correlation' else 'corsplom_panel_correlation'),
+  diag.panel = metOption('diag.panel_corsplom',if(gg) 'corsplom_gg_diagonal' else 'corsplom_panel_diagonal'),
+  pscales= metOption('pscales_corsplom',0),
+  xlab = metOption('xlab_corsplom',NULL),
+  varname.cex = metOption('varname.cex_corsplom',1),
+  main = metOption('main_corsplom',NULL),
+  sub = metOption('sub_corsplom',NULL),
+  col = metOption('col_corsplom','blue'),
+  smooth.col = metOption('smooth.col_corsplom',NULL),
+  smooth.lty = metOption('smooth.lty_corsplom','solid'),
+  smooth.lwd = metOption('smooth.lwd_corsplom',1),
+  smooth.alpha = metOption('smooth.alpha_corsplom',1),
+  density = metOption('density_corsplom',TRUE),
+  diag.label = metOption('diag.label_corsplom','diag_label'),
+  pin = metOption('pin_corsplom','diag_pin'),
+  pin.col = metOption('pin.col_corsplom','darkgrey'),
+  pin.alpha = metOption('pin.alpha_corsplom',1),
+  dens.col = metOption('dens.col_corsplom','grey'),
+  dens.scale = metOption('dens.scale_corsplom',0.2),
+  dens.alpha = metOption('dens.alpha_corsplom',0.5),
+  settings = metOption('settings.corsplom',NULL),
+  padding = metOption('padding_corsplom', 1),
+  as.table = metOption('as.table_corsplom', FALSE),
+  dens.up = metOption('dens.up_corsplom', TRUE), # must not partial match densplot or upper
+  gg = metOption('gg_corsplom',FALSE),
+  verbose = metOption('verbose_corsplom',FALSE),
   ...
 ){
+  if(verbose)cat('this is corsplom_data_frame')
+  if(is.null(smooth.col))smooth.col <- col
   settings <- as.list(settings)
   if(is.null(names(settings))) names(settings) <- character(0)
   stopifnot(length(as.table) == 1, is.logical(as.table))
@@ -121,9 +125,10 @@ corsplom_data_frame <- function(
   x <- x[,xvar,drop=FALSE]
 
   if(gg){
-    if(is.character(upper.panel)) upper.panel <- match.fun(upper.panel)
-    if(is.character(lower.panel)) lower.panel <- match.fun(lower.panel)
-    if(is.character(diag.panel)) diag.panel <- match.fun(diag.panel)
+    tryCatch(match.fun(ylab), error = function(e)ylab)
+    if(is.character(upper.panel)) upper.panel <- tryCatch(match.fun(upper.panel), error = function(e)upper.panel)
+    if(is.character(lower.panel)) lower.panel <- tryCatch(match.fun(lower.panel), error = function(e)lower.panel)
+    if(is.character(diag.panel)) diag.panel <- tryCatch(match.fun(diag.panel), error = function(e)diag.panel)
     ncol <- ncol(x)
     cols <- 1:ncol
     rows <- ncol:1
@@ -152,6 +157,7 @@ corsplom_data_frame <- function(
             bottom <- i != 1
             right  <- i != ncol
           }
+          if(verbose)cat('calling diag.panel')
           p <- diag.panel(
             data = x,
             mapping = aes_string(x = names(x)[[i]]),
@@ -169,28 +175,37 @@ corsplom_data_frame <- function(
             as.table = as.table,
             first = i == 1,
             last = i == ncol,
+            verbose = verbose,
+            ...
+          )
+        }
+        if(i != j && xor(i < j, as.table)){
+          if(verbose)cat('calling lower.panel')
+          p <- lower.panel(
+            data = x,
+            mapping = aes_string(x = names(x)[[j]], y = names(x)[[i]]),
+            col = col,
+            smooth.col = smooth.col,
+            smooth.alpha = smooth.alpha,
+            smooth.lty = smooth.lty,
+            smooth.lwd = smooth.lwd,
+            verbose = verbose,
+            ...
+          )
+        }
+        if(i != j && xor(i > j, as.table)){
+          if(verbose)cat('calling upper.panel')
+          p <- upper.panel(
+            data = x,
+            mapping = aes_string(x = names(x)[[j]], y = names(x)[[i]]),
+            col = col,
+            smooth.col = smooth.col,
+            smooth.alpha = smooth.alpha,
+            smooth.lwd = smooth.lwd,
+            verbose = verbose,
             ...
           )
         }
-        if(i != j && xor(i < j, as.table)) p <- lower.panel(
-          data = x,
-          mapping = aes_string(x = names(x)[[j]], y = names(x)[[i]]),
-          col = col,
-          smooth.col = smooth.col,
-          smooth.alpha = smooth.alpha,
-          smooth.lty = smooth.lty,
-          smooth.lwd = smooth.lwd,
-          ...
-        )
-        if(i != j && xor(i > j, as.table)) p <- upper.panel(
-          data = x,
-          mapping = aes_string(x = names(x)[[j]], y = names(x)[[i]]),
-          col = col,
-          smooth.col = smooth.col,
-          smooth.alpha = smooth.alpha,
-          smooth.lwd = smooth.lwd,
-          ...
-        )
         theme_settings <- list(
           aspect.ratio = 1,
           strip.background = element_blank(),
@@ -239,7 +254,7 @@ corsplom_data_frame <- function(
     class(m) <- c('metaplot_gtable', class(m))
     return(m)
   }
-
+  if(verbose)cat('calling splom')
   splom(
     x,
     upper.panel = upper.panel,
@@ -269,6 +284,7 @@ corsplom_data_frame <- function(
     as_table = as.table,
     par.settings = par.settings,
     dens.up = dens.up,
+    verbose = verbose,
     ...
   )
 }
@@ -287,8 +303,8 @@ corsplom_data_frame <- function(
 corsplom.data.frame <- function(
   x,
   ...,
-  fun = getOption('metaplot_corsplom','corsplom_data_frame'),
-  verbose = metOption('metaplot_verbose_corsplom',FALSE)
+  fun = metOption('corsplom','corsplom_data_frame'),
+  verbose = metOption('verbose_corsplom_data_frame',FALSE)
 ){
   args <- quos(...)
   args <- lapply(args,f_rhs)
@@ -316,15 +332,17 @@ corsplom.data.frame <- function(
 #' @param smooth.lwd ignored
 #' @param smooth.alpha ignored
 #' @param use passed to \code{\link[stats]{cor}}
+#' @param verbose generate messages describing process
 #' @param ... ignored
 #' @keywords internal
 #' @export
 #' @family panel functions
 #' @family corsplom
 corsplom_gg_correlation = function(
-  data, mapping, col = metOption('metaplot_point_col_corsplom_gg','blue'),
-  smooth.col, smooth.lty, smooth.lwd, smooth.alpha, use = 'pairwise.complete.obs', ...
+  data, mapping, col = metOption('col_corsplom_gg','blue'),
+  smooth.col, smooth.lty, smooth.lwd, smooth.alpha, use = 'pairwise.complete.obs', verbose = FALSE, ...
 ){
+  if(verbose)cat('this is corsplom_gg_correlation')
   x <- as.character(mapping$x)
   x <- x[x != '~']
   x <- x[[1]]
@@ -372,6 +390,7 @@ corsplom_gg_correlation = function(
 #' @param smooth.lty smooth line type
 #' @param smooth.lwd smooth line size
 #' @param smooth.alpha smooth alpha
+#' @param verbose generate messages describing process
 #' @param ... passed arguments
 #' @keywords internal
 #' @export
@@ -382,13 +401,15 @@ corsplom_gg_scatter = function(
   mapping,
   method = 'loess',
   se = F,
-  col = metOption('metaplot_point_col_corsplom_gg','blue'),
-  smooth.col = metOption('metaplot_smooth_col_corsplom_gg','blue'),
-  smooth.alpha = metOption('metaplot_smooth_alpha_corsplom_gg',1),
-  smooth.lty = metOption('metaplot_smooth_lty_corsplom_gg','solid'),
-  smooth.lwd = metOption('metaplot_smooth_lwd_corsplom_gg',1),
+  col = metOption('col_corsplom_gg','blue'),
+  smooth.col = metOption('smooth.col_corsplom_gg','blue'),
+  smooth.alpha = metOption('smooth.alpha_corsplom_gg',1),
+  smooth.lty = metOption('smooth.lty_corsplom_gg','solid'),
+  smooth.lwd = metOption('smooth.lwd_corsplom_gg',1),
+  verbose = metOption('verbose_corsplom_gg',FALSE),
   ...
 ){
+  if(verbose)cat('this is corsplom_gg_scatter')
   x <- as.character(mapping$x)
   x <- x[x != '~']
   x <- x[[1]]
@@ -420,7 +441,7 @@ corsplom_gg_scatter = function(
 #' @param data data
 #' @param mapping mapping
 #' @param .data copy of original dataset
-#' @param diag.label label for the diagonal; can be a function of x, varname, .data
+#' @param diag.label label for the diagonal: a function of x, varname, .data
 #' @param pin location for a pin (reference line) in the density region; can be a function of x, varname, .data
 #' @param pin.col color of pin, if any
 #' @param pin.alpha alpha transparency of pin
@@ -431,6 +452,7 @@ corsplom_gg_scatter = function(
 #' @param varname.cex text size multiplier
 #' @param as.table diagonal arranged top-left to bottom-right
 #' @param dens.up whether density plots should face the upper triangle (or lower, if FALSE)
+#' @param verbose generate messages describing process
 #' @param ... passed arguments
 #' @keywords internal
 #' @export
@@ -443,18 +465,20 @@ corsplom_gg_diagonal <- function(
   mapping,
   .data,
   density = TRUE,
-  diag.label = metOption('metaplot_diag_label_corsplom_gg',diag_label),
-  pin = metOption('metaplot_pin_loc_corsplom_gg',diag_pin),
-  pin.col = metOption('metaplot_pin_col_corsplom_gg','darkgrey'),
-  pin.alpha = metOption('metaplot_pin_alpha_corsplom_gg',1),
-  dens.col = metOption('metaplot_dens_col_corsplom_gg','grey'),
-  dens.scale = metOption('metaplot_dens_scale_corsplom_gg',0.2),
-  dens.alpha = metOption('metaplot_dens_alpha_corsplom_gg',0.5),
-  varname.cex = metOption('metaplot_varname_cex_corsplom_gg', 1),
-  as.table = metOption('metaplot_astable_corsplom_gg', TRUE),
-  dens.up = metOption('metaplot_densup_corsplom_gg',TRUE),
+  diag.label = metOption('diag_label_corsplom_gg','diag_label'),
+  pin = metOption('pin_loc_corsplom_gg',diag_pin),
+  pin.col = metOption('pin.col_corsplom_gg','darkgrey'),
+  pin.alpha = metOption('pin.alpha_corsplom_gg',1),
+  dens.col = metOption('dens.col_corsplom_gg','grey'),
+  dens.scale = metOption('dens.scale_corsplom_gg',0.2),
+  dens.alpha = metOption('dens.alpha_corsplom_gg',0.5),
+  varname.cex = metOption('varname.cex_corsplom_gg', 1),
+  as.table = metOption('as.table_corsplom_gg', TRUE),
+  dens.up = metOption('dens.up_corsplom_gg',TRUE),
+  verbose = metOption('verbose_corsplom_gg',FALSE),
   ...
 ){
+  if(verbose)cat('this is corsplom_gg_diagonal')
   stopifnot(is.logical(density))
   density <- rep(density, length.out = 4)
   names(density) <- c('top','right','bottom','left')
@@ -511,7 +535,7 @@ corsplom_gg_diagonal <- function(
       fill = dens.col,
       alpha = dens.alpha
     )
-
+  if(is.character(pin)) pin <- match.fun(pin)
   if(is.function(pin)) pin <- pin(x = x, varname = x, .data = .data, ...)
   ref <- pin
   ref <- as.numeric(ref)
@@ -574,30 +598,32 @@ corsplom_gg_diagonal <- function(
   p
 }
 
-#' Plot a Metaplot GG Splom
+#' Plot a Metaplot_gtable
 #'
-#' Plots a metaplot ggplot2-type splom. Underlying object type is 'gtable'.
-#' Defaults for \code{link{corsplom_data_frame}} prepend class 'metaplot_gtable' to
-#' modify plot and print functionality. This method invokes \code{\link[gridExtra]{grid.arrange}}.
+#' Plots a metaplot_gtable. Underlying object type is 'gtable'.
+#' Defaults for \code{link{corsplom_data_frame}} and \code{link{multiplot}} prepend class 'metaplot_gtable' to
+#' modify plot and print functionality.
 #'
 #' @param x metaplot_gtable
 #' @param y ignored
 #' @param \dots ignored
 #' @keywords internal
 #' @export
-#' @return gtable
+#' @return (invisible) gtable
 #' @family methods
 #' @family corsplom
+#' @importFrom grid grid.newpage grid.draw
 #' @seealso \code{\link{corsplom}}
 
-plot.metaplot_gtable <- function(x, y, ...){
-  class(x) <- setdiff(class(x), 'metaplot_gtable')
-  grid.arrange(x)
+plot.metaplot_gtable <- function(x, ...){
+  grid.newpage()
+  grid.draw(x)
 }
-#' Print a Metaplot GG Splom
+
+#' Print a Metaplot_gtable
 #'
-#' Prints a metaplot ggplot2-type splom. Underlying object type is 'gtable'.
-#' Defaults for \code{link{corsplom_data_frame}} prepend class 'metaplot_gtable' to
+#' Prints a metaplot_gtable. Underlying object type is 'gtable'.
+#' Defaults for \code{link{corsplom_data_frame}} and \code{link{multiplot}} prepend class 'metaplot_gtable' to
 #' modify plot and print functionality. Print method for 'gtable' summarizes the object.
 #' This method invokes the plot method to give interactive behavior more like splom().
 #'
@@ -608,6 +634,6 @@ plot.metaplot_gtable <- function(x, y, ...){
 #' @return gtable
 #' @family methods
 #' @family corsplom
-#' @seealso \code{\link{corsplom}}
+#' @seealso \code{\link{corsplom}} \code{\link{multiplot}}
 
 print.metaplot_gtable <- function(x, ...)plot(x,...)
